#
# spec file for package pidgin-otr
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pidgin-otr
Version:        4.0.2
Release:        lp151.2.2
Summary:        "Off The Record" end-to-end encryption plugin for Pidgin
License:        GPL-2.0+
Group:          Productivity/Networking/Instant Messenger
Url:            https://otr.cypherpunks.ca/
Source:         https://otr.cypherpunks.ca/%{name}-%{version}.tar.gz
Source2:        https://otr.cypherpunks.ca/%{name}-%{version}.tar.gz.asc
Source3:        https://otr.cypherpunks.ca/gpgkey.asc#/pidgin-otr.keyring
# PATCH-FEATURE-UPSTREAM https://bugs.otr.im/plugins/pidgin-otr/issues/127
Source4:        pidgin-otr.metainfo.xml
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libotr) >= 4.0.0
BuildRequires:  pkgconfig(pidgin)

%description
This is a Pidgin plugin which implements Off-the-Record (OTR)
Messaging. OTR allows you to have private conversations over IM by
providing:
 * Encryption.
 * No one else can read your instant messages.
 * Authentication.
 * You are assured the correspondent is who you think it is.
 * Deniability.
 * The messages you send do not have digital signatures that are
   checkable by a third party. Anyone can forge messages after a
   conversation to make them look like they came from you.
   However, during a conversation, your correspondent is assured
   the messages he sees are authentic and unmodified.
 * Perfect forward secrecy.
 * If you lose control of your private keys, no previous
   conversation is compromised.

%package -n pidgin-plugin-otr
Summary:        "Off The Record" end-to-end encryption plugin for Pidgin
Group:          Productivity/Networking/Instant Messenger
Recommends:     pidgin-plugin-otr-lang
# pidgin-otr was last used in openSUSE Leap 42.2.
Provides:       %{name} = %{version}-%{release}
Obsoletes:      %{name} < %{version}-%{release}
%requires_ge    pidgin

%description -n pidgin-plugin-otr
This is a Pidgin plugin which implements Off-the-Record (OTR)
Messaging. OTR allows you to have private conversations over IM by
providing:
 * Encryption.
 * No one else can read your instant messages.
 * Authentication.
 * You are assured the correspondent is who you think it is.
 * Deniability.
 * The messages you send do not have digital signatures that are
   checkable by a third party. Anyone can forge messages after a
   conversation to make them look like they came from you.
   However, during a conversation, your correspondent is assured
   the messages he sees are authentic and unmodified.
 * Perfect forward secrecy.
 * If you lose control of your private keys, no previous
   conversation is compromised.

%lang_package -n pidgin-plugin-otr

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
install -Dm0644 %{SOURCE4} %{buildroot}%{_datadir}/appdata/pidgin-otr.metainfo.xml
%find_lang pidgin-otr

%post -n pidgin-plugin-otr -p /sbin/ldconfig

%postun -n pidgin-plugin-otr -p /sbin/ldconfig

%files -n pidgin-plugin-otr
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README
%{_libdir}/pidgin/%{name}.so
%dir %{_datadir}/appdata/
%{_datadir}/appdata/pidgin-otr.metainfo.xml

%files -n pidgin-plugin-otr-lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Sat Jan 28 2017 mailaender@opensuse.org
- Add pidgin-otr.metainfo.xml from Fedora rh#1293331
* Fri Dec 16 2016 jengelh@inai.de
- Drop --with-pic, this is only meaningful for static libs.
* Fri Dec 16 2016 sor.alexei@meowr.ru
- Rename the pidgin-otr package to pidgin-plugin-otr.
- Separate locales into pidgin-otr-lang.
- Clean description up, update URLs.
* Fri Mar 11 2016 astieger@suse.com
- Update to version 4.0.2 (boo#970498, CVE-2015-8833):
  + Fix use-after-free issue during SMP (CVE-2015-8833).
  + Updated translations.
* Tue Nov 25 2014 dimstar@opensuse.org
- Require a pidgin version >= to what we had during build
  (boo#907000).
* Tue Oct 21 2014 andreas.stieger@gmx.de
- Update to version  4.0.1:
  + Fix max message size for Novell Groupwise.
  + Updated translations.
- Verify source signature: add pidgin-otr.keyring.
- Drop pidgin-otr-fix-max-msg-length-groupwize.patch: fixed
  upstream.
* Mon Feb  3 2014 zaitor@opensuse.org
- Add pidgin-otr-fix-max-msg-length-groupwize.patch, add a default
  max message size for Novell Groupwise (bnc#809052).
* Tue Oct 23 2012 dimstar@opensuse.org
- Update to version 4.0.0:
  + No further changes since 4.0.0 beta2.
- Changes from version 4.0.0 beta2:
  + Fixed an issue that happened when enabling the OTR plugin while
    a conversation is open.
- Changes from version 4.0.0 beta1:
  + The plugin now supports multiple OTR conversations with the
    same buddy who is logged in at multiple locations. In this
    case, a new OTR menu will appear, which allows you to select
    which session an outgoing message is indended for. Note that
    concurrent SMP authentications with the same buddy who is
    logged in multiple times is not yet supported (starting a
    second authentication will end the first).
  + During a private conversation with a buddy, an incoming
    unencrypted message will now trigger the regular incoming
    message notifications. In Pidgin this includes showing the
    message in the top-right notification area, if it is normally
    configured to do so.
  + When a private conversation begins, the plugin will indicate
    whether Pidgin is configured to log the conversation.
  + By default, OTR conversations will not be logged by Pidgin.
  + Fingerprints in the manual authentication dialog are now
    selectable
  + The plugin will no longer delete the OTR menus if a
    non-foreground conversation window is closed.
  + Except on WIN32, the plugin will now set the umask to 0077
    before creating the otr.* files in the purple directory so that
    they end up mode 0600.
  + The menu item now says "Reauthenticate buddy" when the buddy is
    already authenticated.
  + Updated translations.
* Wed May 30 2012 jengelh@inai.de
- Remove unnecessary autoreconf call (there are no patches atm)
- Drop no longer needed libtool BuildRequires.
* Sat May 19 2012 zaitor@opensuse.org
- Update to version 3.2.1:
  + Fix a format string vulnerability (CVE-2012-2369).
  + Set the umask to 0077 before creating the otr.* files in the
    purple directory so that they end up mode 0600.
  + Use /dev/urandom to generate keys instead of /dev/random.
  + Make the fingerprints in the manual authentication dialog
    selectable.
  + Don't delete the OTR menus if a non-foreground conversation
    window is closed.
  + Updated translations.
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Sep 23 2008 crrodriguez@suse.de
- update to version 3.2.0, sync with libotr 3.2.0
* Sat Mar  8 2008 crrodriguez@suse.de
- to be useful. this package should require pidgin
* Mon Nov 12 2007 crrodriguez@suse.de
- rename package to pidgin-otr and update to version 3.1.0 needed
  to support libotr 3.1.0
* Mon Jun 11 2007 ro@suse.de
- replace gaim-devel by pidgin-devel in buildreq
- add pidgin patch (diff from pidgin-otr-3.0.0)
* Thu Jan 11 2007 sbrabec@suse.cz
- Prefix changed to /usr.
* Fri Dec  1 2006 sbrabec@suse.cz
- Build correctly in older products.
* Sat Oct  7 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov  9 2005 bwhiteley@suse.de
- update to version 3.0.0
* Tue Nov  1 2005 bwhiteley@suse.de
- First time suse package (version 2.0.2)
